<?php

namespace Litecms\Desa\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Litecms\Desa\Http\Requests\PnddkUserRequest;
use Litecms\Desa\Interfaces\PnddkRepositoryInterface;
use Response;
use User;

class PnddkUserController extends UserController
{
    /**
     * Initialize pnddk controller.
     *
     * @param type PnddkRepositoryInterface $pnddk
     *
     * @return type
     */
    public function __construct(PnddkRepositoryInterface $pnddk)
    {
        $this->model = $pnddk;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PnddkUserRequest $request)
    {
        $pnddks = $this->model->all();

        $this->theme->prependTitle(trans('desa::pnddk.names').' :: ');

        return $this->theme->of('desa::user.pnddk.index', compact('pnddks'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PnddkUserRequest $request, $role, $id)
    {
        $pnddk = $this->model->find($id);

        return $this->theme->of('desa::user.pnddk.show', compact('pnddk'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PnddkUserRequest $request)
    {
        $pnddk = $this->model->findOrNew(0);

        Former::populate($pnddk);

        return $this->theme->of('desa::user.pnddk.create', compact('pnddk'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PnddkUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $pnddk = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('desa::pnddk.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PnddkUserRequest $request, $role, $id)
    {
        $pnddk = $this->model->find($id);

        Former::populate($pnddk);

        return $this->theme->of('desa::user.pnddk.edit', compact('pnddk'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PnddkUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $pnddk = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('desa::pnddk.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PnddkUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('desa::pnddk.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
